==> Statemate4.6.1.7Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Dataport/wwhdata/js/search/pairs/pair193.js <==
function FileData_Pairs(x)
{
x.t("subroutine","syntax");
x.t("subroutine","function");
x.t("stm_missing_name","stm_missing_field");
x.t("table","related");
x.t("description","sb_id");
x.t("related","input");
x.t("action","activity");
x.t("arguments","argument");
x.t("type","description");
x.t("type","stm_list");
x.t("element","status");
x.t("stm_id_out_of_range","stm_illegal_parameter");
x.t("stm_id_not_found","stm_file_not_found");
x.t("list","local");
x.t("list","functions");
x.t("status","codes");
x.t("status","int");
x.t("status","code");
x.t("stm_id","element");
x.t("codes","stm_success");
x.t("argument","input/");
x.t("local","data");
x.t("stm_list","elements");
x.t("int","function");
x.t("input","subroutine");
x.t("functions","list");
x.t("functions","stm_r_xx_truth_table_local_data");
x.t("stm_error_in_file","stm_id_out_of_range");
x.t("stm_file_not_found","stm_missing_name");
x.t("syntax","stm_r_xx_truth_table_local_data");
x.t("activity","subroutine");
x.t("function","type");
x.t("function","status");
x.t("single-element","functions");
x.t("&status","arguments");
x.t("code","status");
x.t("output","type");
x.t("data","elements");
x.t("defined","truth");
x.t("sb_id","stm_id");
x.t("sb_id","&status");
x.t("truth","table");
x.t("stm_r_xx_truth_table_local_data","single-element");
x.t("stm_r_xx_truth_table_local_data","sb_id");
x.t("stm_r_xx_truth_table_local_data","stm_r_xx_truth_table_local_data");
x.t("stm_r_xx_truth_table_local_data","returns");
x.t("elements","action");
x.t("elements","defined");
x.t("returns","list");
x.t("input/","output");
x.t("stm_success","stm_error_in_file");
x.t("stm_illegal_parameter","stm_id_not_found");
}

==> Statemate4.6.1.10Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Dataport/wwhdata/js/search/pairs/pair193.js <==
function FileData_Pairs(x)
{
x.t("subroutine","syntax");
x.t("subroutine","function");
x.t("stm_missing_name","stm_missing_field");
x.t("table","related");
x.t("description","sb_id");
x.t("related","input");
x.t("arguments","argument");
x.t("type","description");
x.t("type","stm_list");
x.t("element","status");
x.t("stm_id_out_of_range","stm_illegal_parameter");
x.t("stm_id_not_found","stm_file_not_found");
x.t("list","local");
x.t("list","functions");
x.t("status","codes");
x.t("status","int");
x.t("status","code");
x.t("stm_id","element");
x.t("codes","stm_success");
x.t("argument","input/");
x.t("local","data");
x.t("stm_list","elements");
x.t("int","function");
x.t("input","subroutine");
x.t("functions","list");
x.t("functions","stm_r_xx_truth_table_local_data");
x.t("stm_error_in_file","stm_id_out_of_range");
x.t("stm_file_not_found","stm_missing_name");
x.t("syntax","stm_r_xx_truth_table_local_data");
x.t("function","type");
x.t("function","status");
x.t("single-element","functions");
x.t("&status","arguments");
x.t("code","status");
x.t("output","type");
x.t("data","elements");
x.t("defined","truth");
x.t("sb_id","stm_id");
x.t("sb_id","&status");
x.t("truth","table");
x.t("stm_r_xx_truth_table_local_data","single-element");
x.t("stm_r_xx_truth_table_local_data","sb_id");
x.t("stm_r_xx_truth_table_local_data","stm_r_xx_truth_table_local_data");
x.t("stm_r_xx_truth_table_local_data","returns");
x.t("elements","subroutine");
x.t("elements","defined");
x.t("returns","list");
x.t("input/","output");
x.t("stm_success","stm_error_in_file");
x.t("stm_illegal_parameter","stm_id_not_found");
}
